# Antidote - A Skiddies buster tool

[![Build Status](https://travis-ci.com/StrinTH/Antidote.svg?branch=master)](https://travis-ci.com/StrinTH/Antidote)
[![Build Status](https://img.shields.io/badge/stage-alpha-orange)]()

AntiDOTE v0.2
![logo](./assets/logo2.png)
AntiDOTE v0.2

--------------

```sh
    Project under development
```

## Description:

Being a script kid is not bad. But using someone else's tools and script to harm others is absolutely bad. And this thing is actually needed right now.

## Setup:

```sh
$ python3 -m pip install antidotes
```

## Features:

* This tool contains a scanner module to scan the given urls for infection by most used and popular scripts.

* It contains a special module for 'Saycheese' or other similar 'camera spoofing' scripts. Inherited from <https://github.com/StrinTH/saycheese-antidote>.

* This tool can be run in background and keeps checking for malicious url from clipboard and will scan it automatically.

* This tool is almost depended on requests package. and some less used others for basic operatons.

* Some new features will be added soon, to play with skids.

### _Miscellaneous Feature:_
##### In case, if you want to run it for always, you can run assistance.pyw by clicking on it, which will keep tracking clipboard urls and scan it.

## Modules description:

* ### Antidote Saycheese:

    This module is antidote for all those tools and scripts on github and all other platforms which are being used by skids for playing with innocents.

    #### Special Feature:

    You can tease them by sending your message on a image.

    *In case, if you can play with SVG payloads, then may be you can get shell in his/her system through this tool. ;)*

* ### Antidote Shellphish:

    This tool is one of the most popular phishing tool among these kids, originally made by @thelinuxchoice (username changed  and Privated now).
    tool use send messages as text with this module.

    #### Special Feature:

    You can send message as text but you can be more creative with texts also. ;)

* ### Antidote Whatsapp Phisher:

    There are a lot of tools available on github, similar to
    <https://github.com/Ignitetch/whatsapp-phishing> (Not targeting to developer, but to the misusers)
    so You can send your message as text to them.

* ### Antidote z-shadow:

    **z-shadow** and **shadowave** was the most famous free phising site for skids (Down from a month).

    This module manipulate complete process of transmission of zshadow server and attacker client.

    #### Special Feature:
    
    * This tool bypasses weak human verification by zshadow and shadowave site.
    
    * You can use this to spam your message as text to them. After a while, their account will be removed by the site bots itself for overloading.

        ```sh
        Note: As z-shadow and shadowaves are down more than for a month, this tool is not tested so much. 
        but it was working for more than half a year uninteruptully.
        ```

## TO-DO list:

* **[Done]** Add auto scan clipboard copied URLs. [9cc7fb7](https://github.com/StrinTH/Antidote/commit/9cc7fb7)

* Add anti saythanks module (In case needed)

* Make GUI for this tool to handle actions for URLs through corner sidebar.

### **Support authors**:

[![Donate](./assets/default-pink.png)](https://www.buymeacoffee.com/6dciIwk)

[![Donate](./assets/-460.png)](https://paypal.me/0x0is1?locale.x=en_GB)